@@ -1,24 +1,8 @@
 /*
- * This file is part of kdev-python
- * Copyright 2013  Sven Brauch <svenbrauch@gmail.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
+    SPDX-FileCopyrightText: 2013 Sven Brauch <svenbrauch@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #ifndef DOCFILEWIZARD_H
 #define DOCFILEWIZARD_H
@@ -57,12 +41,12 @@ private:
     QPushButton* runButton;
     QPushButton* saveButton;
 
-public slots:
+public Q_SLOTS:
     // Calls python to actually generate the docfile
     bool run();
     void updateOutputFilename(const QString& newModuleName);
     void processScriptOutput();
-    void processFinished(int);
+    void processFinished(int, QProcess::ExitStatus);
     void saveAndClose();
 };
 
