@@ -27,15 +27,19 @@ DumpChain::DumpChain()
 {
 }
 
-void DumpChain::dump( DUContext * context, bool imported )
+void DumpChain::dump(const DUContext* context, bool imported)
 {
     if( !context )
         return;
-    qCDebug(KDEV_PYTHON_DUCHAIN) << QString( indent*2, QLatin1Char(' ') ) << (imported ? "==import==> Context " : "New Context ") << context->scopeIdentifier(true) << context->transformFromLocalRevision(context->range()) << " " << context << " " << (dynamic_cast<TopDUContext*>(context) ? "top-context" : "");
+    qCDebug(KDEV_PYTHON_DUCHAIN) << QString(indent * 2, QLatin1Char(' '))
+                                 << (imported ? "==import==> Context " : "New Context ")
+                                 << context->scopeIdentifier(true)
+                                 << context->transformFromLocalRevision(context->range()) << " " << context << " "
+                                 << (dynamic_cast<const TopDUContext*>(context) ? "top-context" : "");
     if (!imported)
     {
-        for (Declaration* dec : context->localDeclarations())
-        {
+        const auto localDeclarations = context->localDeclarations();
+        for (Declaration* dec : localDeclarations) {
             const auto uses = dec->uses();
             qCDebug(KDEV_PYTHON_DUCHAIN) << QString( (indent+1)*2, QLatin1Char(' ') ) << "Declaration: " << dec->toString() << " [" << dec->qualifiedIdentifier() << "]  "<< dec << "(internal ctx" << dec->internalContext() << ")" << context->transformFromLocalRevision(dec->range()) << ", "<< ( dec->isDefinition() ? "definition, " : "declaration, " ) << uses.count() << "use(s)";
             for (auto it = uses.constBegin(); it != uses.constEnd(); ++it)
@@ -51,12 +55,12 @@ void DumpChain::dump( DUContext * context, bool imported )
     ++indent;
     if (!imported)
     {
-        for (const DUContext::Import& parent : context->importedParentContexts())
-        {
-            dump(parent.context(dynamic_cast<TopDUContext*>(context)), true);
+        const auto parentContexts = context->importedParentContexts();
+        for (const DUContext::Import& parent : parentContexts) {
+            dump(parent.context(dynamic_cast<const TopDUContext*>(context)), true);
         }
-        for (DUContext* child : context->childContexts())
-        {
+        const auto childContexts = context->childContexts();
+        for (DUContext* child : childContexts) {
             dump(child);
         }
     }
